@@ -4,7 +4,7 @@
 #  (C) Paul Evans, 2019-2025 -- leonerd@leonerd.org.uk
 
 package Future::IO::ImplBase;
-our $VERSION = '0.17_002';
+our $VERSION = '0.17_003';
 
 use v5.14;
 use warnings;
@@ -195,8 +195,14 @@ sub _send1
    my ( $f, $fh, $data, $flags, $to ) = @_;
 
    my $waitf = $self->ready_for_write( $fh )->on_done( sub {
-      my $len = $fh->send( $data, $flags, $to );
-      if( defined $len ) {
+      my $len;
+      # IO::Socket->send itself might die
+      my $e = eval { $len = $fh->send( $data, $flags, $to ); 1 } ? undef : $@;
+
+      if( defined $e ) {
+         $f->fail( "send: $e\n", send => $fh, $! );
+      }
+      elsif( defined $len ) {
          $f->done( $len );
       }
       elsif( $! == EAGAIN or $! == EWOULDBLOCK ) {
