@@ -4,7 +4,7 @@
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
 package Future::IO::System;
-our $VERSION = '0.17_002';
+our $VERSION = '0.17_003';
 
 use v5.14;
 use warnings;
@@ -143,7 +143,7 @@ sub run
       if( $want_in ) {
          close $infh[0];
          push @f, Future::IO->syswrite_exactly( $infh[1], $params{in} )
-            ->then( sub { close $infh[1]; Future->done() } );
+            ->then( sub { Future->done() } );
       }
 
       if( $want_out ) {
